function EyePlotter(InSignal)
%
% Usage: EyePlotter(InSignal)
%
% Purpose = This module is to generate an eye diagram.
%
% Input(InSignal) = Single channel signal (optical/electrical), Size = [1 x DataLength]
% Output = Eye diagram figure 
%
% Note1) Time axis covers two bit periods.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%=====================================================================================
global BitRate SampleRate samplesperbit Bits

s_type = isreal(InSignal);

t_eye = 1e9*(0:1/SampleRate:(2/BitRate - 1/SampleRate));% 2 bit periods in [ns] unit

  
   for k= 1:(Bits/2)

	eye_d(:,k)=InSignal(2*(k-1)*samplesperbit+1:2*k*samplesperbit);
    
   end
   
   
   if s_type == 1; % Electrical signal case
      
   figure
   plot(t_eye,1e3*eye_d)
   grid on
   title('Eye Diagram _ Electrical Signal','FontSize',12)
   xlabel('time [ns]','FontSize',12)
   ylabel('Magnitude [mA or mV]','FontSize',12)
   
   else            % Optical signal case
      
   figure
   plot(t_eye,1e3*(eye_d.*conj(eye_d)),'r') ;% 1e3 for [mW] 
   grid on
   title('Eye Diagram _ Optical Signal','FontSize',12)
   xlabel('time [ns]','FontSize',12)
   ylabel('Power [mW]','FontSize',12)

   
   end
   
