function y = ModulatorAmplitude(carrier,data,ModulationIndex)
%
% Usage: y = ModulatorAmplitude(carrier,data,ModulationIndex)
%
% Purpose = This module simulates an ideal amplitude modulator.
%
% Input1(carrier) = optical carrier.
% Input2(data) = electrical modulation signal
%
% Output Signal(y) = Modulated optical signal
%
%=== Physical Parameters === 
%  ModulationIndex = range [0,1] (Default = 0.9)
%
% Note)Extinction Ratio [dB] = -10log10(1-ModulationIndex)
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==============================================================
if nargin<3, ModulationIndex=0.9; end

% data sequence with finite extinction ratio
data_f_ext = (1-ModulationIndex) + ModulationIndex.*data; 

y = sqrt(data_f_ext).*carrier;
