function y = ModulatorElectroabsorp(carrier,data,ModulationIndex,ChirpFactor)
%
% Usage: y = ModulatorElectroabsorp(carrier,data,ModulationIndex,ChirpFactor)
%
% Purpose = This module simulates an electroabsorption modulator.
%
% Input1(carrier) = optical carrier.
% Input2(data) = electrical modulation signal
%
% Output Signal(y) = Modulated optical signal
%
%=== Physical Parameters ===
%  ModulationIndex = range [0,1] (Default = 0.9)
%  ChirpFactor = range ]-inf,inf[ (Default = 0)
%
% Note)Extinction Ratio [dB] = -10log10(1-ModulationIndex)
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==============================================================
if nargin<4,
  ChirpFactor = 0;
end
if nargin<3,
   ModulationIndex = 0.9;
end
if nargin<2, 
  help ModulatorElectroabsorption; 
  return; 
end

data_f_ext = (1-ModulationIndex)+ModulationIndex.*data; %data sequence with finite extinction ratio
EAPhase = .5*ChirpFactor*log(data_f_ext);

y = sqrt(data_f_ext).*carrier.*exp(1i*EAPhase);
