function y = ModulatorFrequency(carrier,data,FreqDeviation)
%
% Usage: y = ModulatorFrequency(carrier,data,FreqDeviation)
%
% Purpose = This module simulates an ideal frequency modulator.
%
% Input1(carrier) = optical carrier.
% Input2(data) = electrical modulation signal
%
% Output Signal(y) = Modulated optical signal
%
% === Physical Parameters with default value ===
%  FreqDeviation  = Frequency difference between '0' and '1'
%                 = 10e9 ;[Hz]  (default)
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================
global SampleRate

if nargin<3, FreqDeviation  = 10e9; end

Phase = 2*pi*cumsum(FreqDeviation*(data-0.5))/SampleRate; % y = data
y = carrier.*exp(1i*Phase); % 
