function y = OpticalFilterInverted_Rectangular(Optical_input,FilterCenter,Rec_BW) 
%
% Usage: y = OpticalFilterInverted_Rectangular(Optical_input,FilterCenter,Rec_BW) 
%
% Purpose = This module represents an ideal inverted rectangular shaped optical filter. (phase = 0).
%
% Input Signal(Optical_input) = Optical Signal 
% Output Signal(y) = Optical Signal 
%
% ==== Physical Parameters ===== 
% FilterCenter = Deviation in [Hz] from the 'Ref_Frequency' [Hz]
%              = 0  (default)
% Rec_BW = Bandwidth [Hz]
%        = 4*BitRate (default)
%
%   (global variables) f_sym DataLength BitRate
%
% Note1) Insertion Loss is NOT included. (IL can be modeled separately using function 'Attenuator'.)
% Note2) FilterCenter = 0 corresponds to 'Ref_frequency'.  
%        Physical frequency = 'Ref_frequency' + 'f_sym'
% Note3) abs(FilterCenter) should be less than Fs/2, that is, less than max(f_sym).
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global f_sym DataLength BitRate

if nargin<3,
 Rec_BW = 4*BitRate;
end
if nargin<2,
   FilterCenter = 0;
end

%======== Define the filter transfer function ================
% Magnitude transfer function for optical field

Mag_f = ones(1,DataLength);
dum = zeros(1,DataLength);
f_dev = f_sym - FilterCenter; BW2 = Rec_BW/2;

Ri = find(f_dev > BW2);
Le = find(f_dev < -BW2);
Mag_f(Ri) = dum(Ri); Mag_f(Le) = dum(Le);

Mag_f_inverted = sqrt(1-Mag_f.*Mag_f);

%=====================================================================================

%========= Filtering input signal with the defined optical filter =================
E_out_f = fft(Optical_input);
Filtered = fftshift(Mag_f_inverted).*E_out_f;%'ifftshift' inverses 'fftshift'

%====== Filtered Optical Field in time domain
y = ifft(Filtered);
