function y = PowerCombiner4_1(x1,x2,x3,x4,alpha1,alpha2,alpha3)
%
% Usage: y = PowerCombiner4_1(x1,x2,x3,x4,alpha1,alpha2,alpha3)
%
% Purpose = This module combines four optical input signals.
%
% Input Signal(x1,x2,x3,x4) = Optical Filed Signals
%
% Output Signal(y) = Optical Field Signal 
%
% === Physical Parameter ===
% alpha1,alpha2,alpha3 = coupling coefficient [0,1] 
%                      = 0.5 (default)
%
% Note) Due to CrossCoupler, at the ouput port, x1=0 degree phase difference,
%       x2&x3 = 90 degree phase difference, x4 = 180 degree phase difference.
%
%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================

if nargin<7, 
    alpha3=0.5;
end
if nargin<6, 
    alpha2=0.5;
end
if nargin<5, 
    alpha1=0.5;
end

[yyl,yy2] = CrossCoupler(x1,x2,alpha1);
[yy3,yy4] = CrossCoupler(x3,x4,alpha2);

[y,dummy] = CrossCoupler(yyl,yy3,alpha3);
