function y = RZCoder(info_bits,RZRatio)
%
% Usage: y = RZCoder(info_bits,RZRatio)
%
% Purpose = This module generates a sampled, RZ coded signal.
%
% Input Signal(info_bits) = Bit sequence (integer)
% Output Signal(y) = Electrical RZ coded signal (Duty cycle defiend by RZRatio.)
%
% === Physical Parameters === 
% RZRatio = Ratio of high level duration to bit time [0,1]
%         = 0.5 (default)
%
%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%=======================================================================
global samplesperbit

if nargin<2, RZRatio = 0.5; end

Prepost_Rz = round((1-RZRatio)/2*samplesperbit);
Rz_pulsedefined = [zeros(1,Prepost_Rz) ones(1,(samplesperbit-2*Prepost_Rz)) zeros(1,Prepost_Rz)];

RZelectrical = Rz_pulsedefined'*info_bits;
y = RZelectrical(:);
