function y = RiseTimeAdjust(ElectricalPreshaped,RiseTime)
%
% Usage: y = RiseTimeAdjust(ElectricalPreshaped,RiseTime)
%
% Purpose = This module is a Gaussian filter that transforms electrical preshaped pulses 
%          into smoother output pulses with a user defined rise-time.
%
% Input Signal (ElectricalPreshaped) = Electrical Preshaped(NRZ/RZ) Pulses 
% Output Signal (y) = Electrical pulses with a user defined rise-time.
%
% === Physical Parameters with typical values ===
%  RiseTime  [sec] = Defined by the 10% to 90% amplitude values of the signal 
%                  = 1/16/BitRate  (default)
%
%  (global variables) DataLength SampleRate BitRate t_range
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==============================================================
global DataLength SampleRate BitRate t_range 

if nargin<2, RiseTime =1/16/BitRate; end

%Define the impule response of the pulse shaping filter
T = 4*RiseTime/3;  % impulse response parameter
Td = DataLength/(2*SampleRate);% shift the impulse response to the center of time window
impulse_response = 2*exp(-(2*(t_range-Td)/T).^2)/(T*sqrt(pi));%

f_response = fft(impulse_response);
freq_pulse_sym = fft(ElectricalPreshaped);

%RiseTime Adjusted pulse train
%'fliplr' is used to match to the original bit sequence
y = fliplr(abs(fftshift(ifft(f_response.*freq_pulse_sym'))))/SampleRate;

