function [y,info_bits] = TxExtMod_MZLaser_RZ(UnmodulatedPower,Linewidth,ExtinctionRatio,SymmetryFactor,ChirpSign,...
                         RZRatio,PreSpaces,PostSpaces,RiseTime)
%
% Usage: [y,info_bits] = TxExtMod_MZLaser_RZ(UnmodulatedPower,Linewidth,ExtinctionRatio,SymmetryFactor,ChirpSign...
%                        RZRatio,PreSpaces,PostSpaces,RiseTime)
%
% Purpose = This module is to simulate an externally modulater laser by Mach-Zehnder using RZ line coding.
%          
% TxExtMod_MZLaser_RZ = info_bits(PRBS) + RZCoder + RiseTimeAdjust
%                              + LaserCW + Modulator_Mach_Zehnder
%
% Input = Not required.
% Output1(y) = Optical modulated signal 
% Output2(info_bits) = info_bits for BER calculation at the receiver.
%
%=== Physical Parameters with Default Values=======
% UnmodulatedPower= 1e-3 (default);  % [W] CW Laser 
% Linewidth= 10e6 (default);     %[Hz] CW Laser
%
% ExtinctionRatio [dB]   [0,inf[   default = 30 %  Modulator_Mach_Zehnder
% SymmetryFactor  []     [-1 1]    default = -1 %  Modulator_Mach_Zehnder
% ChirpSign       []      +/-1     default = +1 %  Modulator_Mach_Zehnder
% 
% RZRatio = 0.5 (default) %[0,1]  RZCoder
%
% PreSpaces = 2 (default); % number of leading zero bits, infobits_PRBS
% PostSpaces = 2 (default); % number of trailing zero bits, infobits_PRBS
%
% RiseTime = 1/16/BitRate (default);% RiseTimeAdjust  [sec]
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global BitRate

if nargin <9
    RiseTime = 1/16/BitRate;
end
if nargin <8
    PostSpaces = 2;   
end    
if nargin<7,
    PreSpaces = 2;
end
if nargin<6,
    RZRatio = 0.5;
end
if nargin<5,
   ChirpSign = 1;
end
if nargin<4,
   SymmetryFactor = -1;
end
if nargin<3,
   ExtinctionRatio = 30;
end
if nargin<2,
   Linewidth= 10e6;
end
if nargin==0,
   UnmodulatedPower= 1e-3;
end

%===================================================================
info_bits = infobits_PRBS(PreSpaces,PostSpaces); 
ElectricalPreshaped = RZCoder(info_bits,RZRatio);
Elec_mod = RiseTimeAdjust(ElectricalPreshaped,RiseTime); 
%========================================================================
% CW Optical Signal
E_CW = LaserCW(UnmodulatedPower,Linewidth);
%========================================================================

y = Modulator_Mach_Zehnder(E_CW,Elec_mod,ExtinctionRatio,SymmetryFactor,ChirpSign);

