function y = WDM_DeMux_Flattop(Optical_input,BW_3dB,n_filter,IL) 
%
% Usage: y = WDM_DeMux_Flattop(Optical_input,BW_3dB,n_filter,IL) 
%
% Purpose = This module represents a DeMux with Flattop(super-Gaussian) shaped optical filters.
%
% Input Signal(Optical_input) = (Composite) Optical Signal (size = [1 x DataLength])
% Output Signal(y) = Demuxed (filtered & sorted) Optical Signal (size = [ChannelNumber x DataLength])
%
% ==== Physical Parameters ===== 
%   BW_3dB = 3dB bandwidth [Hz]
%          = 4*BitRate (default)
%   n_filter = super gaussain factor (>1 for super Gaussian, =1 if Gaussian)
%            = 2 (default)
%   IL  = insertion loss [dB]
%       = 3 (default)
%
% Note1) Output size = FilterNumber by DataLength
% Note2) All the filter characteristicas (shape, bandwidth, and IL) are assumed equal.
% Note3) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%=================================================================================================
global  ChannelNumber ChannelSpacing BitRate

if nargin<4,
   IL = 3;
end
if nargin<3,
  n_filter = 2 ;
end
if nargin<2,
 BW_3dB = 4*BitRate;
end

AfterIL = Attenuator(Optical_input,IL);

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;

if FilterNumber == 1
   
    y = OpticalFilter_Flattop(AfterIL,0,BW_3dB,n_filter);
        
else
   
    for k = 1:FilterNumber
    
          
          FilterCenter(k) = FilterSpacing*(k - (FilterNumber+1)/2);
          y(k,:) = OpticalFilter_Flattop(AfterIL,FilterCenter(k),BW_3dB,n_filter);%                
       
     end  
     
 end    
    
