function y = WDM_DeMux_Rect(Optical_input,Rec_BW,IL)  
%
% Usage: y = WDM_DeMux_Rect(Optical_input,Rec_BW,IL) 
%
% Purpose = This module represents a DeMux with Rectangular optical filters.
%
% Input Signal(Optical_input) = (Composite) Optical Signal (size = [1 x DataLength])
% Output Signal(y) = Demuxed (filtered & sorted) Optical Signal (size = [ChannelNumber x DataLength])
%
% ==== Physical Parameters ===== 
%   Rec_BW = Bandwidth of the filter [Hz]
%          = 4*BitRate (default)
%   IL  = insertion loss [dB]
%       = 3  (default) 
%
% Note1) Output size = FilterNumber by DataLength
% Note2) All the filter characteristicas (shape, bandwidth, and IL) are assumed equal.
% Note3) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee
%=================================================================================================
global BitRate ChannelNumber ChannelSpacing

if nargin<3
    IL = 3;
end
if nargin<2,
 Rec_BW = 4*BitRate;
end

AfterIL = Attenuator(Optical_input,IL);

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;


if FilterNumber == 1
   
    y = OpticalFilter_Rectangular(AfterIL,0,Rec_BW);
        
else
   
    for k = 1:FilterNumber
              
          FilterCenter(k) = FilterSpacing*(k - (FilterNumber+1)/2);
          y(k,:) = OpticalFilter_Rectangular(AfterIL,FilterCenter(k),Rec_BW);%                
       
     end  
     
 end    
    
