function y = WDM_Mux_Bessel(Optical_composite,BW_3dB,FilterOrder,IL)  
%
% Usage: y = WDM_Mux_Bessel(Optical_composite,BW_3dB,FilterOrder,IL)
%
% Purpose = This module represents a Mux with Bessel shaped optical filters.
%
% Input Signal(Optical_composite) = (Composite) Optical Signal (size = [ChannelNumber x DataLength])
% Output Signal(y) = Optical Signal (size = [1 x DataLength])
%
% ==== Physical Parameters ===== 
%   BW_3dB = 3dB bandwidth [Hz]
%          = 4*BitRate (default)
%   FilterOrder = positive integer [1,100]
%               = 3 (default)
%   IL  = insertion loss [dB]
%       = 3 (default)
%
% Note1) All the filter characteristicas (shape, bandwidth, and IL) are assumed equal.
% Note2) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%===============================================================================================
global ChannelNumber ChannelSpacing BitRate

if nargin<4,
   IL = 3;
end
if nargin<3,
  FilterOrder = 3 ;
end
if nargin<2,
 BW_3dB = 4*BitRate;
end


[a,b] = size(Optical_composite);

if a == 1  ; %single channel case
   Optical_input = Optical_composite;
else
   Optical_input = sum(Optical_composite); %Ideal Muxing
end

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;

%Phase of filter banks

if FilterNumber == 1
   
    x = OpticalFilter_Bessel(Optical_input,0,BW_3dB,FilterOrder);% 
    y = Attenuator(x,IL);
    
else
    
    for k = 1:FilterNumber
    
          
          FilterCenter(k) = FilterSpacing*(k - (ChannelNumber+1)/2);
          
          x(k,:) = OpticalFilter_Bessel(Optical_input,FilterCenter(k),BW_3dB,FilterOrder);% 

     end     
    
      filtered_x = sum (x);
      y = Attenuator(filtered_x,IL);
       
 end    
    
