function y = infobits_PRBS_Fixed(PreSpaces,PostSpaces)
%
% Usage: y = infobits_PRBS_Fixed(PreSpaces,PostSpaces)
%
% Purpose = This module generates PRBS with fixed number of ones (50%).
%
% Input Signal = Not required
% Output Signal = Random binary sequence with fixed number of ones
%
% ===  Parameters =====
% PreSpaces = Number of leading zero bits 
%           = 2 (default)
% PostSpaces = Number of trailing zero bits
%            = 2 (default)
%
% Bits(bit number) should be larger than (PreSpaces+PostSpaces). 
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%=======================================================================
global Bits

if nargin<2,
   PostSpaces = 2;
end

if nargin<1,
   PreSpaces = 2;
end

nn = Bits-PreSpaces-PostSpaces;
if nn <= 0,fprintf('Bits(bit number) should be larger than (PreSpaces+PostSpaces)!'); return; end

CenterBits = Bits-PreSpaces-PostSpaces;
PositionofOnes = randperm(CenterBits);

NumberofOnes = Bits/2;

for i=1:NumberofOnes
   
   center_infobits(PositionofOnes(i))=1;
   center_infobits(PositionofOnes(i+NumberofOnes-(PreSpaces+PostSpaces)))=0;
   
end

y = [zeros(1,PreSpaces) center_infobits zeros(1,PostSpaces)];
